@@ -31,6 +31,7 @@
 #include "core/storagemodelbase.h"
 #include "core/widgetbase.h"
 #include "messagelistutil.h"
+#include "messagelistutil_p.h"
 
 #include "MessageCore/StringUtil"
 
@@ -56,11 +57,11 @@ class Q_DECL_HIDDEN View::Private
 {
 public:
     Private(View *owner, Widget *parent)
-        : q(owner), mWidget(parent), mModel(Q_NULLPTR), mDelegate(new Delegate(owner)),
-          mAggregation(Q_NULLPTR), mTheme(Q_NULLPTR), mNeedToApplyThemeColumns(false),
-          mLastCurrentItem(Q_NULLPTR), mFirstShow(true), mSaveThemeColumnStateOnSectionResize(true),
-          mSaveThemeColumnStateTimer(Q_NULLPTR), mApplyThemeColumnsTimer(Q_NULLPTR),
-          mIgnoreUpdateGeometries(false) { }
+        : q(owner), mWidget(parent), mModel(nullptr), mDelegate(new Delegate(owner)),
+          mAggregation(nullptr), mTheme(nullptr), mNeedToApplyThemeColumns(false),
+          mLastCurrentItem(nullptr), mSaveThemeColumnStateOnSectionResize(true),
+          mSaveThemeColumnStateTimer(nullptr), mApplyThemeColumnsTimer(nullptr),
+          mLastViewportWidth(-1), mIgnoreUpdateGeometries(false) { }
 
     void expandFullThread(const QModelIndex &index);
 
@@ -75,18 +76,16 @@ public:
     bool mNeedToApplyThemeColumns;            ///< Flag signaling a pending application of theme columns
     Item *mLastCurrentItem;
     QPoint mMousePressPosition;
-    bool mFirstShow;
     bool mSaveThemeColumnStateOnSectionResize;      ///< This is used to filter out programmatic column resizes in slotSectionResized().
     QTimer *mSaveThemeColumnStateTimer;             ///< Used to trigger a delayed "save theme state"
     QTimer *mApplyThemeColumnsTimer;                ///< Used to trigger a delayed "apply theme columns"
+    int mLastViewportWidth;
     bool mIgnoreUpdateGeometries;                   ///< Shall we ignore the "update geometries" calls ?
 };
 
 View::View(Widget *pParent)
     : QTreeView(pParent), d(new Private(this, pParent))
 {
-    setFocusPolicy(Qt::NoFocus);
-
     d->mSaveThemeColumnStateTimer = new QTimer();
     connect(d->mSaveThemeColumnStateTimer, &QTimer::timeout, this, &View::saveThemeColumnState);
 
@@ -140,12 +139,12 @@ View::~View()
     delete d->mApplyThemeColumnsTimer;
 
     // Zero out the theme, aggregation and ApplyThemeColumnsTimer so Model will not cause accesses to them in its destruction process
-    d->mApplyThemeColumnsTimer = Q_NULLPTR;
+    d->mApplyThemeColumnsTimer = nullptr;
 
-    d->mTheme = Q_NULLPTR;
-    d->mAggregation = Q_NULLPTR;
+    d->mTheme = nullptr;
+    d->mAggregation = nullptr;
 
-    delete d; d = Q_NULLPTR;
+    delete d; d = nullptr;
 }
 
 Model *View::model() const
@@ -291,9 +290,6 @@ void View::modelJobBatchTerminated()
 void View::modelHasBeenReset()
 {
     // This is called by Model when it has been reset.
-    if (d && d->mNeedToApplyThemeColumns) {
-        applyThemeColumns();
-    }
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -317,8 +313,8 @@ void View::modelHasBeenReset()
 //
 // - Display the column state context popup menu and handle its actions
 //
-// - Apply the theme columns when the theme changes, when the model changes or in certain
-//   ugly corner cases when the widget is resized or shown.
+// - Apply the theme columns when the theme changes, when the model changes or when
+//   the widget is resized.
 //
 // - Avoid saving a corrupted column state in that QHeaderView can be found *very* frequently.
 //
@@ -352,6 +348,8 @@ void View::applyThemeColumns()
     if (viewport()->width() < 1) {
         return;    // insane width
     }
+    const int viewportWidth = viewport()->width();
+    d->mLastViewportWidth = viewportWidth;
 
     // Now we want to distribute the available width on all the visible columns.
     //
@@ -411,19 +409,19 @@ void View::applyThemeColumns()
     // Now compute somewhat "proportional" widths.
     idx = 0;
 
-    QList< int > lColumnWidths;
+    QList< double > lColumnWidths;
     lColumnWidths.reserve(columns.count());
     int totalVisibleWidth = 0;
     end = columns.constEnd();
     for (it = columns.constBegin(); it != end; ++it) {
-        int savedWidth = (*it)->currentWidth();
-        int hintWidth = savedWidth > 0 ? savedWidth : lColumnSizeHints[ idx ];
-        int realWidth;
+        double savedWidth = (*it)->currentWidth();
+        double hintWidth = savedWidth > 0 ? savedWidth : lColumnSizeHints.at(idx);
+        double realWidth;
 
         if ((*it)->currentlyVisible() || (idx == 0)) {
             if ((*it)->containsTextItems()) {
                 // the column contains text items, it should get more space (if possible)
-                realWidth = ((hintWidth * viewport()->width()) / totalVisibleWidthHint);
+                realWidth = ((hintWidth * viewportWidth) / totalVisibleWidthHint);
             } else {
                 // the column contains no text items, it should get exactly its hint/saved width.
                 realWidth = hintWidth;
@@ -458,61 +456,56 @@ void View::applyThemeColumns()
 
     idx = 0;
 
-    if (totalVisibleWidth != viewport()->width()) {
+    if (totalVisibleWidth != viewportWidth) {
         // The estimated widths were not using exactly the available space.
-        if (totalVisibleWidth < viewport()->width()) {
+        if (totalVisibleWidth < viewportWidth) {
             // We were using less space than available.
 
             // Give the additional space to the text columns
             // also give more space to the first ones and less space to the last ones
-            int available = viewport()->width() - totalVisibleWidth;
+            qreal available = viewportWidth - totalVisibleWidth;
 
-            end = columns.end();
-            for (it = columns.begin(); it != end; ++it) {
-                if (((*it)->currentlyVisible() || (idx == 0)) && (*it)->containsTextItems()) {
+            for (int idx = 0; idx < columns.count(); ++idx) {
+                Theme::Column *column = columns.at(idx);
+                if ((column->currentlyVisible() || (idx == 0)) && column->containsTextItems()) {
                     // give more space to this column
-                    available >>= 1; // eat half of the available space
+                    available /= 2; // eat half of the available space
                     lColumnWidths[ idx ] += available; // and give it to this column
                     if (available < 1) {
                         break;    // no more space to give away
                     }
                 }
-
-                idx++;
             }
 
             // if any space is still available, give it to the first column
-            if (available) {
+            if (available >= 1) {
                 lColumnWidths[ 0 ] += available;
             }
         } else {
             // We were using more space than available
 
-            // If the columns span just a little bit more than the view then
+            // If the columns span more than the view then
             // try to squeeze them in order to make them fit
-            if (totalVisibleWidth < (viewport()->width() + 100)) {
-                int missing = totalVisibleWidth - viewport()->width();
-                int count = lColumnWidths.count();
+            double missing = totalVisibleWidth - viewportWidth;
+            if (missing > 0) {
+                const int count = lColumnWidths.count();
+                idx = count - 1;
 
-                if (missing > 0) {
-                    idx = count - 1;
-
-                    while (idx >= 0) {
-                        if (columns.at(idx)->currentlyVisible() || (idx == 0)) {
-                            int chop = lColumnWidths[ idx ] - lColumnSizeHints[ idx ];
-                            if (chop > 0) {
-                                if (chop > missing) {
-                                    chop = missing;
-                                }
-                                lColumnWidths[ idx ] -= chop;
-                                missing -= chop;
-                                if (missing < 1) {
-                                    break;    // no more space to recover
-                                }
+                while (idx >= 0) {
+                    if (columns.at(idx)->currentlyVisible() || (idx == 0)) {
+                        double chop = lColumnWidths.at(idx) - lColumnSizeHints.at(idx);
+                        if (chop > 0) {
+                            if (chop > missing) {
+                                chop = missing;
                             }
-                        } // else it's invisible
-                        idx--;
-                    }
+                            lColumnWidths[ idx ] -= chop;
+                            missing -= chop;
+                            if (missing < 1) {
+                                break;    // no more space to recover
+                            }
+                        }
+                    } // else it's invisible
+                    idx--;
                 }
             }
         }
@@ -532,8 +525,6 @@ void View::applyThemeColumns()
 
     idx = 0;
 
-    //qCDebug(MESSAGELIST_LOG) << "Entering column show/hide loop";
-
     end = columns.constEnd();
     for (it = columns.constBegin(); it != end; ++it) {
         bool visible = (idx == 0) || (*it)->currentlyVisible();
@@ -552,12 +543,11 @@ void View::applyThemeColumns()
     end = columns.constEnd();
     for (it = columns.constBegin(); it != end; ++it) {
         if ((*it)->currentlyVisible()) {
-            //qCDebug(MESSAGELIST_LOG) << "Resize section " << idx << " to " << lColumnWidths[ idx ];
-            const int columnWidth(lColumnWidths[ idx ]);
+            const double columnWidth(lColumnWidths.at(idx));
             (*it)->setCurrentWidth(columnWidth);
             //Laurent Bug 358855 - message list column widths lost when program closed
             // I need to investigate if this code is still necessary (all method)
-            //header()->resizeSection(idx, columnWidth);
+            header()->resizeSection(idx, static_cast<int>(columnWidth));
         } else {
             (*it)->setCurrentWidth(-1);
         }
@@ -659,7 +649,7 @@ void View::resizeEvent(QResizeEvent *e)
         return;    // don't play with
     }
 
-    if ((!d->mFirstShow) && d->mNeedToApplyThemeColumns) {
+    if (d->mLastViewportWidth != viewport()->width()) {
         triggerDelayedApplyThemeColumns();
     }
 
@@ -732,16 +722,6 @@ int View::sizeHintForColumn(int logicalColumnIndex) const
 void View::showEvent(QShowEvent *e)
 {
     QTreeView::showEvent(e);
-    if (d->mFirstShow) {
-        // If we're shown for the first time and the theme has been already set
-        // then we need to reapply the theme column widths since the previous
-        // application probably used invalid widths.
-        //
-        if (d->mTheme) {
-            triggerDelayedApplyThemeColumns();
-        }
-        d->mFirstShow = false;
-    }
 }
 
 void View::slotHeaderContextMenuRequested(const QPoint &pnt)
@@ -861,7 +841,7 @@ Item *View::currentItem() const
 {
     QModelIndex idx = currentIndex();
     if (!idx.isValid()) {
-        return Q_NULLPTR;
+        return nullptr;
     }
     Item *it = static_cast< Item * >(idx.internalPointer());
     Q_ASSERT(it);
@@ -872,7 +852,7 @@ MessageItem *View::currentMessageItem(bool selectIfNeeded) const
 {
     Item *it = currentItem();
     if (!it || (it->type() != Item::Message)) {
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     if (selectIfNeeded) {
@@ -1137,7 +1117,7 @@ static inline bool message_type_matches(Item *item, MessageTypeFilter messageTyp
 Item *View::messageItemAfter(Item *referenceItem, MessageTypeFilter messageTypeFilter, bool loop)
 {
     if (!storageModel()) {
-        return Q_NULLPTR;    // no folder
+        return nullptr;    // no folder
     }
 
     // find the item to start with
@@ -1170,11 +1150,11 @@ Item *View::messageItemAfter(Item *referenceItem, MessageTypeFilter messageTypeF
                 Q_ASSERT(below);   // must exist (we had a current item)
 
                 if (below == referenceItem) {
-                    return Q_NULLPTR;    // only one item in folder: loop complete
+                    return nullptr;    // only one item in folder: loop complete
                 }
             } else {
                 // looping not requested
-                return Q_NULLPTR;
+                return nullptr;
             }
         }
 
@@ -1183,7 +1163,7 @@ Item *View::messageItemAfter(Item *referenceItem, MessageTypeFilter messageTypeF
         below = d->mModel->rootItem()->itemBelow();
 
         if (!below) {
-            return Q_NULLPTR;    // folder empty
+            return nullptr;    // folder empty
         }
     }
 
@@ -1225,13 +1205,13 @@ Item *View::messageItemAfter(Item *referenceItem, MessageTypeFilter messageTypeF
                 // else mi == 0 and below == 0: we have started from the beginning and reached the end (it will fail the test below and exit)
             } else {
                 // looping not requested: nothing more to do
-                return Q_NULLPTR;
+                return nullptr;
             }
         }
 
         if (below == referenceItem) {
             Q_ASSERT(loop);
-            return Q_NULLPTR; // looped and returned back to the first message
+            return nullptr; // looped and returned back to the first message
         }
 
         parentIndex = d->mModel->index(below->parent(), 0);
@@ -1245,7 +1225,7 @@ Item *View::messageItemAfter(Item *referenceItem, MessageTypeFilter messageTypeF
 
 Item *View::firstMessageItem(MessageTypeFilter messageTypeFilter)
 {
-    return messageItemAfter(Q_NULLPTR, messageTypeFilter, false);
+    return messageItemAfter(nullptr, messageTypeFilter, false);
 }
 
 Item *View::nextMessageItem(MessageTypeFilter messageTypeFilter, bool loop)
@@ -1267,7 +1247,7 @@ Item *View::deepestExpandedChild(Item *referenceItem) const
 Item *View::messageItemBefore(Item *referenceItem, MessageTypeFilter messageTypeFilter, bool loop)
 {
     if (!storageModel()) {
-        return Q_NULLPTR;    // no folder
+        return nullptr;    // no folder
     }
 
     // find the item to start with
@@ -1276,7 +1256,7 @@ Item *View::messageItemBefore(Item *referenceItem, MessageTypeFilter messageType
     if (referenceItem) {
         Item *parent = referenceItem->parent();
         Item *siblingAbove = parent ?
-                             parent->itemAboveChild(referenceItem) : Q_NULLPTR;
+                             parent->itemAboveChild(referenceItem) : nullptr;
         // there was a current item: we start just above it
         if ((siblingAbove && siblingAbove != referenceItem && siblingAbove != parent) &&
                 (siblingAbove->childItemCount() > 0) &&
@@ -1302,11 +1282,11 @@ Item *View::messageItemBefore(Item *referenceItem, MessageTypeFilter messageType
                 Q_ASSERT(above != d->mModel->rootItem());
 
                 if (above == referenceItem) {
-                    return Q_NULLPTR;    // only one item in folder: loop complete
+                    return nullptr;    // only one item in folder: loop complete
                 }
             } else {
                 // looping not requested
-                return Q_NULLPTR;
+                return nullptr;
             }
 
         }
@@ -1315,7 +1295,7 @@ Item *View::messageItemBefore(Item *referenceItem, MessageTypeFilter messageType
         above = d->mModel->rootItem()->deepestItem();
 
         if (!above || !above->parent() || (above == d->mModel->rootItem())) {
-            return Q_NULLPTR;    // folder empty
+            return nullptr;    // folder empty
         }
     }
 
@@ -1357,17 +1337,17 @@ Item *View::messageItemBefore(Item *referenceItem, MessageTypeFilter messageType
                 // else mi == 0 and above == 0: we have started from the end and reached the beginning (it will fail the test below and exit)
             } else {
                 // looping not requested: nothing more to do
-                return Q_NULLPTR;
+                return nullptr;
             }
         }
 
         if (above == referenceItem) {
             Q_ASSERT(loop);
-            return Q_NULLPTR; // looped and returned back to the first message
+            return nullptr; // looped and returned back to the first message
         }
 
         if (!above->parent()) {
-            return Q_NULLPTR;
+            return nullptr;
         }
 
         parentIndex = d->mModel->index(above->parent(), 0);
@@ -1381,7 +1361,7 @@ Item *View::messageItemBefore(Item *referenceItem, MessageTypeFilter messageType
 
 Item *View::lastMessageItem(MessageTypeFilter messageTypeFilter)
 {
-    return messageItemBefore(Q_NULLPTR, messageTypeFilter, false);
+    return messageItemBefore(nullptr, messageTypeFilter, false);
 }
 
 Item *View::previousMessageItem(MessageTypeFilter messageTypeFilter, bool loop)
@@ -1406,7 +1386,7 @@ void View::growOrShrinkExistingSelection(const QModelIndex &newSelectedIndex, bo
     // find out the actual selection range
     const QItemSelection selection = selectionModel()->selection();
 
-    foreach (const QItemSelectionRange &range, selection) {
+    for (const QItemSelectionRange &range : selection) {
         // We're asking the model for the index as range.topLeft() and range.bottomRight()
         // can return indexes in invisible columns which have a null visualRect().
         // Column 0, instead, is always visible.
@@ -1443,8 +1423,8 @@ void View::growOrShrinkExistingSelection(const QModelIndex &newSelectedIndex, bo
                 selectionModel()->select(newSelectedIndex, QItemSelectionModel::Rows | QItemSelectionModel::Select);
             } else {
                 // selecting something below the top: shrink selection
-                QModelIndexList selectedIndexes = selection.indexes();
-                foreach (const QModelIndex &idx, selectedIndexes) {
+                const QModelIndexList selectedIndexes = selection.indexes();
+                for (const QModelIndex &idx : selectedIndexes) {
                     if ((idx.column() == 0) && (visualRect(idx).top() > selectedVisualCoordinate)) {
                         selectionModel()->select(idx, QItemSelectionModel::Rows | QItemSelectionModel::Deselect);
                     }
@@ -1456,8 +1436,8 @@ void View::growOrShrinkExistingSelection(const QModelIndex &newSelectedIndex, bo
                 selectionModel()->select(newSelectedIndex, QItemSelectionModel::Rows | QItemSelectionModel::Select);
             } else {
                 // selecting something above bottom: shrink selection
-                QModelIndexList selectedIndexes = selection.indexes();
-                foreach (const QModelIndex &idx, selectedIndexes) {
+                const QModelIndexList selectedIndexes = selection.indexes();
+                for (const QModelIndex &idx : selectedIndexes) {
                     if ((idx.column() == 0) && (visualRect(idx).top() < selectedVisualCoordinate)) {
                         selectionModel()->select(idx, QItemSelectionModel::Rows | QItemSelectionModel::Deselect);
                     }
@@ -1482,8 +1462,6 @@ bool View::selectNextMessageItem(
         return false;
     }
 
-    setFocus();
-
     if (it->parent() != d->mModel->rootItem()) {
         ensureDisplayedWithParentsExpanded(it);
     }
@@ -1526,8 +1504,6 @@ bool View::selectPreviousMessageItem(
         return false;
     }
 
-    setFocus();
-
     if (it->parent() != d->mModel->rootItem()) {
         ensureDisplayedWithParentsExpanded(it);
     }
@@ -1565,8 +1541,6 @@ bool View::focusNextMessageItem(MessageTypeFilter messageTypeFilter, bool center
         return false;
     }
 
-    setFocus();
-
     if (it->parent() != d->mModel->rootItem()) {
         ensureDisplayedWithParentsExpanded(it);
     }
@@ -1591,8 +1565,6 @@ bool View::focusPreviousMessageItem(MessageTypeFilter messageTypeFilter, bool ce
         return false;
     }
 
-    setFocus();
-
     if (it->parent() != d->mModel->rootItem()) {
         ensureDisplayedWithParentsExpanded(it);
     }
@@ -1617,8 +1589,6 @@ void View::selectFocusedMessageItem(bool centerItem)
         return;
     }
 
-    setFocus();
-
     if (selectionModel()->isSelected(idx)) {
         return;
     }
@@ -1643,7 +1613,6 @@ bool View::selectFirstMessageItem(MessageTypeFilter messageTypeFilter, bool cent
 
     Q_ASSERT(it != d->mModel->rootItem());   // must never happen (obviously)
 
-    setFocus();
     ensureDisplayedWithParentsExpanded(it);
 
     QModelIndex idx = d->mModel->index(it, 0);
@@ -1672,7 +1641,6 @@ bool View::selectLastMessageItem(MessageTypeFilter messageTypeFilter, bool cente
 
     Q_ASSERT(it != d->mModel->rootItem());
 
-    setFocus();
     ensureDisplayedWithParentsExpanded(it);
 
     QModelIndex idx = d->mModel->index(it, 0);
@@ -1763,14 +1731,14 @@ void View::markMessageItemsAsAboutToBeRemoved(QList< MessageItem * > &items, boo
 
     bool clearingEntireSelection = true;
 
-    QModelIndexList selectedIndexes = selectionModel()->selectedRows(0);
+    const QModelIndexList selectedIndexes = selectionModel()->selectedRows(0);
 
     if (selectedIndexes.count() > items.count()) {
         // the selection is bigger: we can't clear it completely
         clearingEntireSelection = false;
     } else {
         // the selection has same size or is smaller: we can clear it completely with our removal
-        foreach (const QModelIndex &selectedIndex, selectedIndexes) {
+        for (const QModelIndex &selectedIndex : selectedIndexes) {
             Q_ASSERT(selectedIndex.isValid());
             Q_ASSERT(selectedIndex.column() == 0);
 
@@ -1807,7 +1775,7 @@ void View::markMessageItemsAsAboutToBeRemoved(QList< MessageItem * > &items, boo
             Item *next = messageItemAfter(aMessage, MessageTypeAny, false);
             if (!next) {
                 // no way
-                aMessage = Q_NULLPTR;
+                aMessage = nullptr;
                 break;
             }
             Q_ASSERT(next->type() == Item::Message);
@@ -1825,7 +1793,7 @@ void View::markMessageItemsAsAboutToBeRemoved(QList< MessageItem * > &items, boo
                 Item *prev = messageItemBefore(aMessage, MessageTypeAny, false);
                 if (!prev) {
                     // no way
-                    aMessage = Q_NULLPTR;
+                    aMessage = nullptr;
                     break;
                 }
                 Q_ASSERT(prev->type() == Item::Message);
@@ -1950,11 +1918,8 @@ void View::slotSelectionChanged(const QItemSelection &, const QItemSelection &)
     QModelIndex current = currentIndex();
 
     if (!current.isValid()) {
-        if (d->mLastCurrentItem) {
-            d->mWidget->viewMessageSelected(Q_NULLPTR);
-            d->mLastCurrentItem = Q_NULLPTR;
-        }
-        d->mWidget->viewMessageSelected(Q_NULLPTR);
+        d->mLastCurrentItem = nullptr;
+        d->mWidget->viewMessageSelected(nullptr);
         d->mWidget->viewSelectionChanged();
         return;
     }
@@ -1988,8 +1953,8 @@ void View::slotSelectionChanged(const QItemSelection &, const QItemSelection &)
     break;
     case Item::GroupHeader:
         if (d->mLastCurrentItem) {
-            d->mWidget->viewMessageSelected(Q_NULLPTR);
-            d->mLastCurrentItem = Q_NULLPTR;
+            d->mWidget->viewMessageSelected(nullptr);
+            d->mLastCurrentItem = nullptr;
         }
         break;
     default:
@@ -2395,7 +2360,7 @@ bool View::event(QEvent *e)
                    "</div>" \
                    "</td>" \
                    "</tr>"
-               ).arg(txtColorName).arg(bckColorName).arg(mi->subject().toHtmlEscaped()).arg(textDirection);
+               ).arg(txtColorName, bckColorName, mi->subject().toHtmlEscaped(), textDirection);
 
         tip += QLatin1String(
                    "<tr>" \
@@ -2416,12 +2381,12 @@ bool View::event(QEvent *e)
                 "</tr>");
 
         if (textIsLeftToRight) {
-            tip += htmlCodeForStandardRow.arg(i18n("From")).arg(MessageCore::StringUtil::stripEmailAddr(mi->sender()));
-            tip += htmlCodeForStandardRow.arg(i18nc("Receiver of the email", "To")).arg(MessageCore::StringUtil::stripEmailAddr(mi->receiver()));
-            tip += htmlCodeForStandardRow.arg(i18n("Date")).arg(mi->formattedDate());
+            tip += htmlCodeForStandardRow.arg(i18n("From"), mi->displaySender());
+            tip += htmlCodeForStandardRow.arg(i18nc("Receiver of the email", "To"), mi->displayReceiver());
+            tip += htmlCodeForStandardRow.arg(i18n("Date"), mi->formattedDate());
         } else {
-            tip += htmlCodeForStandardRow.arg(MessageCore::StringUtil::stripEmailAddr(mi->sender())).arg(i18n("From"));
-            tip += htmlCodeForStandardRow.arg(MessageCore::StringUtil::stripEmailAddr(mi->receiver())).arg(i18nc("Receiver of the email", "To"));
+            tip += htmlCodeForStandardRow.arg(mi->displaySender(), i18n("From"));
+            tip += htmlCodeForStandardRow.arg(mi->displayReceiver(), i18nc("Receiver of the email", "To"));
             tip += htmlCodeForStandardRow.arg(mi->formattedDate(), i18n("Date"));
         }
 
@@ -2460,7 +2425,7 @@ bool View::event(QEvent *e)
         }
 
         tip += QLatin1String(
-                   "</table" \
+                   "</table>" \
                    "</td>" \
                    "</tr>"
                );
